#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['cjswidget']

package_data = \
{'': ['*'],
 'cjswidget': ['static/*',
               'static\\cjswidget/*',
               'templates/*',
               'templates\\cjswidget/*']}

install_requires = \
['shortuuid']

setup(name='django-cjswidget',
      version='0.4.1',
      description='A replacement for the Select widget with fancy new features - powered by choices.js!',
      author='Luke Rogers',
      author_email='luke@dmptr.com',
      url='https://github.com/dmptrluke/django-cjswidget',
      packages=packages,
      package_data=package_data,
      install_requires=install_requires,
      python_requires='>=3.6',
     )
